@@ -1,6 +1,13 @@
-/* demo/gokuraku/jump/jump1.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -23,7 +30,7 @@ static real c_b28 = .1f;
 static real c_b29 = .5f;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -36,7 +43,7 @@ static real c_b29 = .5f;
     static integer n;
     static real t, x[400], y[400], dt;
     static integer iws;
-    extern doublereal rngu3_(integer *);
+    extern real rngu0_(integer *);
     static integer iseed;
     extern /* Subroutine */ int grfig_(void), grcls_(void), grfrm_(void), 
 	    gropn_(integer *), uulin_(integer *, real *, real *), uumrk_(
@@ -50,7 +57,7 @@ static real c_b29 = .5f;
     static cilist io___7 = { 0, 5, 0, 0, 0 };
 
 
-/* -- ǡ 1 ---- */
+/* -- データ 1 ---- */
     dt = .015747318295739349f;
     for (n = 1; n <= 400; ++n) {
 	t = dt * (n - 1);
@@ -58,7 +65,7 @@ static real c_b29 = .5f;
 	y[n - 1] = cos(t * 5.f) * 5.f;
 /* L10: */
     }
-/* --  1 ---- */
+/* -- グラフ 1 ---- */
     s_wsle(&io___6);
     do_lio(&c__9, &c__1, " WORKSTATION ID (I)  ? ;", (ftnlen)24);
     e_wsle();
@@ -75,16 +82,16 @@ static real c_b29 = .5f;
     ussttl_("X1", "", "Y1", "", (ftnlen)2, (ftnlen)0, (ftnlen)2, (ftnlen)0);
     usdaxs_();
     uulin_(&c__400, x, y);
-/* -- ǡ 2 ---- */
+/* -- データ 2 ---- */
     iseed = 1;
-    x[0] = (rngu3_(&iseed) - .5f) * 2.f;
+    x[0] = (rngu0_(&iseed) - .5f) * 2.f;
     for (n = 2; n <= 400; ++n) {
-	x[n - 1] = (rngu3_(&iseed) - .5f) * 2.f;
+	x[n - 1] = (rngu0_(&iseed) - .5f) * 2.f;
 	y[n - 2] = x[n - 1];
 /* L20: */
     }
     y[399] = x[0];
-/* --  2 ---- */
+/* -- グラフ 2 ---- */
     grfig_();
     grswnd_(&c_b22, &c_b23, &c_b22, &c_b23);
     grsvpt_(&c_b11, &c_b14, &c_b28, &c_b29);
