@@ -1,6 +1,13 @@
-/* demo/math2/fftlib/fftl02.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -60,7 +67,7 @@ static integer c__36 = 36;
     extern /* Subroutine */ int rfftf_(integer *, real *, real *), rffti_(
 	    integer *, real *);
     static real azero, wrfft[87], error;
-    extern doublereal trunc_(real *);
+    extern real trunc_(real *);
     extern /* Subroutine */ int ezfftb_(integer *, real *, real *, real *, 
 	    real *, real *), ezfftf_(integer *, real *, real *, real *, real *
 	    , real *), ezffti_(integer *, real *);
@@ -155,14 +162,14 @@ static integer c__36 = 36;
 
 /* TEST RESULTS OF RFFTF */
 
-    error = (r__1 = 36.f - rldat[0], dabs(r__1));
+    error = (r__1 = 36.f - rldat[0], abs(r__1));
     for (i__ = 2; i__ <= 36; ++i__) {
 /* L15: */
 /* Computing MAX */
-	r__2 = error, r__3 = (r__1 = rldat[i__ - 1], dabs(r__1));
-	error = dmax(r__2,r__3);
+	r__2 = error, r__3 = (r__1 = rldat[i__ - 1], abs(r__1));
+	error = max(r__2,r__3);
     }
-    r__1 = 1.f + tol * dabs(error);
+    r__1 = 1.f + tol * abs(error);
     if (trunc_(&r__1) - 1.f == 0.f) {
 	ier1 = 0;
     } else {
@@ -187,10 +194,10 @@ static integer c__36 = 36;
     for (i__ = 1; i__ <= 36; ++i__) {
 /* L25: */
 /* Computing MAX */
-	r__2 = error, r__3 = (r__1 = 1.f - rldat[i__ - 1], dabs(r__1));
-	error = dmax(r__2,r__3);
+	r__2 = error, r__3 = (r__1 = 1.f - rldat[i__ - 1], abs(r__1));
+	error = max(r__2,r__3);
     }
-    r__1 = 1.f + tol * dabs(error);
+    r__1 = 1.f + tol * abs(error);
     if (trunc_(&r__1) - 1.f == 0.f) {
 	ier2 = 0;
     } else {
@@ -214,15 +221,15 @@ static integer c__36 = 36;
 
 /* TEST RESULTS OF EZFFTF */
 
-    error = (r__1 = azero - 1.f, dabs(r__1));
+    error = (r__1 = azero - 1.f, abs(r__1));
     for (i__ = 1; i__ <= 18; ++i__) {
 /* L35: */
 /* Computing MAX */
-	r__3 = (r__1 = a[i__ - 1], dabs(r__1)) + (r__2 = b[i__ - 1], dabs(
-		r__2));
-	error = dmax(r__3,error);
+	r__3 = (r__1 = a[i__ - 1], abs(r__1)) + (r__2 = b[i__ - 1], abs(r__2))
+		;
+	error = max(r__3,error);
     }
-    r__1 = 1.f + tol * dabs(error);
+    r__1 = 1.f + tol * abs(error);
     if (trunc_(&r__1) - 1.f == 0.f) {
 	ier3 = 0;
     } else {
@@ -248,10 +255,10 @@ static integer c__36 = 36;
     for (i__ = 1; i__ <= 36; ++i__) {
 /* L45: */
 /* Computing MAX */
-	r__2 = (r__1 = 1.f - rldat[i__ - 1], dabs(r__1));
-	error = dmax(r__2,error);
+	r__2 = (r__1 = 1.f - rldat[i__ - 1], abs(r__1));
+	error = max(r__2,error);
     }
-    r__1 = 1.f + tol * dabs(error);
+    r__1 = 1.f + tol * abs(error);
     if (trunc_(&r__1) - 1.f == 0.f) {
 	ier4 = 0;
     } else {
@@ -273,7 +280,7 @@ static integer c__36 = 36;
     return 0;
 } /* tfftpk_ */
 
-doublereal trunc_(real *x)
+real trunc_(real *x)
 {
     /* System generated locals */
     real ret_val;
