@@ -1,6 +1,13 @@
-/* src/env1/fonts/cvfont.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -17,7 +24,7 @@ static integer c__6000 = 6000;
 /* ----------------------------------------------------------------------- */
 /*     PROGRAM FOR FONT FILE CONVERSION                       (95/05/31) */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -117,10 +124,14 @@ L20:
 /* L10: */
     }
 /*         / CHECK END OF SEGMENT / */
-    if (jd != 0 && kx[jd - 1] == -64) {
-	lend = TRUE_;
-	iposx[nc - 1] = iplst + 1;
-	iplst = (nl - 1 << 3) + jd + iplst;
+    if (jd != 0) {
+	if (kx[jd - 1] == -64) {
+	    lend = TRUE_;
+	    iposx[nc - 1] = iplst + 1;
+	    iplst = (nl - 1 << 3) + jd + iplst;
+	} else {
+	    lend = FALSE_;
+	}
     } else {
 	lend = FALSE_;
     }
