@@ -1,6 +1,13 @@
-/* src/grph1/sgpack/sglqnp.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -8,27 +15,27 @@
 /* Table of constant values */
 
 static integer c__3 = 3;
-static integer c__25 = 25;
+static integer c__26 = 26;
 
 /* ----------------------------------------------------------------------- */
 /*     LOGICAL PARAMETER CONTROL */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int sglqnp_0_(int n__, integer *ncp, char *cp, integer *idx, 
 	logical *lpara, integer *in, ftnlen cp_len)
 {
     /* Initialized data */
 
-    static char cparas[8*25] = "LCLIP   " "LCHAR   " "LLNINT  " "LGCINT  " 
+    static char cparas[8*26] = "LCLIP   " "LCHAR   " "LLNINT  " "LGCINT  " 
 	    "LSOFTF  " "LCL2TN  " "LCNTL   " "LFULL   " "LFPROP  " "LROT    " 
 	    "LBUFF   " "LCURV   " "LPROP   " "LUARW   " "LARROW  " "LATONE  " 
 	    "LDEG    " "LCORNER " "LTITLE  " "LWIDE   " "LFGBG   " "L2TO3   " 
-	    "LXLOG3  " "LYLOG3  " "LZLOG3  ";
-    static logical lx[25] = { FALSE_,FALSE_,FALSE_,TRUE_,FALSE_,FALSE_,FALSE_,
+	    "LXLOG3  " "LYLOG3  " "LZLOG3  " "LMRKFNT ";
+    static logical lx[26] = { FALSE_,FALSE_,FALSE_,TRUE_,TRUE_,FALSE_,FALSE_,
 	    FALSE_,TRUE_,FALSE_,TRUE_,TRUE_,TRUE_,TRUE_,FALSE_,FALSE_,TRUE_,
-	    FALSE_,TRUE_,FALSE_,FALSE_,FALSE_,FALSE_,FALSE_,FALSE_ };
-    static char cparal[40*25] = "ENABLE_CLIPPING                         " 
+	    FALSE_,TRUE_,FALSE_,FALSE_,FALSE_,FALSE_,FALSE_,FALSE_,TRUE_ };
+    static char cparal[40*26] = "ENABLE_CLIPPING                         " 
 	    "ENABLE_LINE_LABELING                    " "ENABLE_LINEAR_INTERP"
 	    "OLATION             " "ENABLE_GREATCIRCLE_INTERPOLATION        " 
 	    "ENABLE_SOFTFILL                         " "ENABLE_COLOR_SUBSTIT"
@@ -44,7 +51,8 @@ static integer c__25 = 25;
 	    "****LWIDE                               " "****LFGBG           "
 	    "                    " "****L2TO3                               " 
 	    "++++LXLOG3                              " "++++LYLOG3          "
-	    "                    " "++++LZLOG3                              ";
+	    "                    " "++++LZLOG3                              " 
+	    "USE_DCLMARKER_FONT                      ";
     static logical lfirst = TRUE_;
 
     /* System generated locals */
@@ -75,12 +83,12 @@ static integer c__25 = 25;
 	}
 
 /*     / LONG  NAME / */
-    *ncp = 25;
+    *ncp = 26;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_sglqid:
-    for (n = 1; n <= 25; ++n) {
+    for (n = 1; n <= 26; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *idx = n;
@@ -98,7 +106,7 @@ L_sglqid:
 /* ----------------------------------------------------------------------- */
 
 L_sglqcp:
-    if (1 <= *idx && *idx <= 25) {
+    if (1 <= *idx && *idx <= 26) {
 	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
     } else {
 	msgdmp_("E", "SGLQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -108,7 +116,7 @@ L_sglqcp:
 /* ----------------------------------------------------------------------- */
 
 L_sglqcl:
-    if (1 <= *idx && *idx <= 25) {
+    if (1 <= *idx && *idx <= 26) {
 	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
     } else {
 	msgdmp_("E", "SGLQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -119,11 +127,11 @@ L_sglqcl:
 
 L_sglqvl:
     if (lfirst) {
-	rtlget_("SG", cparas, lx, &c__25, (ftnlen)2, (ftnlen)8);
-	rllget_(cparal, lx, &c__25, (ftnlen)40);
+	rtlget_("SG", cparas, lx, &c__26, (ftnlen)2, (ftnlen)8);
+	rllget_(cparal, lx, &c__26, (ftnlen)40);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 25) {
+    if (1 <= *idx && *idx <= 26) {
 	*lpara = lx[*idx - 1];
     } else {
 	msgdmp_("E", "SGLQVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -134,11 +142,11 @@ L_sglqvl:
 
 L_sglsvl:
     if (lfirst) {
-	rtlget_("SG", cparas, lx, &c__25, (ftnlen)2, (ftnlen)8);
-	rllget_(cparal, lx, &c__25, (ftnlen)40);
+	rtlget_("SG", cparas, lx, &c__26, (ftnlen)2, (ftnlen)8);
+	rllget_(cparal, lx, &c__26, (ftnlen)40);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 25) {
+    if (1 <= *idx && *idx <= 26) {
 	lx[*idx - 1] = *lpara;
     } else {
 	msgdmp_("E", "SGLSVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -148,7 +156,7 @@ L_sglsvl:
 /* ----------------------------------------------------------------------- */
 
 L_sglqin:
-    for (n = 1; n <= 25; ++n) {
+    for (n = 1; n <= 26; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *in = n;
