@@ -1,6 +1,13 @@
-/* src/grph1/sgpack/sgopn.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -14,7 +21,7 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     CONTROL */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int sgopn_0_(int n__, integer *iws)
 {
@@ -92,10 +99,10 @@ L_sginit:
 /*     / SET DUMMY TRANSFORMATION / */
 /* Computing MIN */
     r__1 = 1.f, r__2 = wx0 / wy0;
-    rxm = dmin(r__1,r__2);
+    rxm = min(r__1,r__2);
 /* Computing MIN */
     r__1 = wy0 / wx0;
-    rym = dmin(r__1,1.f);
+    rym = min(r__1,1.f);
     stswtr_(&c_b9, &rxm, &c_b9, &rym, &c_b9, &wx0, &c_b9, &wy0, &itr);
     sgsvpt_(&c_b9, &rxm, &c_b9, &rym);
     sgswnd_(&c_b9, &c_b16, &c_b9, &c_b16);
@@ -132,10 +139,10 @@ L_sgfrm:
 	wyl = yamax - yamin;
 /* Computing MIN */
 	r__1 = 1.f, r__2 = wxl / wyl;
-	rxm = dmin(r__1,r__2);
+	rxm = min(r__1,r__2);
 /* Computing MIN */
 	r__1 = wyl / wxl;
-	rym = dmin(r__1,1.f);
+	rym = min(r__1,1.f);
 	stswtr_(&c_b9, &rxm, &c_b9, &rym, &xamin, &xamax, &yamin, &yamax, &
 		itr);
 	slpcnr_();
@@ -150,10 +157,10 @@ L_sgfrm:
     if (lfull) {
 /* Computing MIN */
 	r__1 = 1.f, r__2 = wxl / wyl;
-	rxm = dmin(r__1,r__2);
+	rxm = min(r__1,r__2);
 /* Computing MIN */
 	r__1 = wyl / wxl;
-	rym = dmin(r__1,1.f);
+	rym = min(r__1,1.f);
 	stswtr_(&c_b9, &rxm, &c_b9, &rym, &xamin, &xamax, &yamin, &yamax, &
 		itr);
     } else {
