@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -13,7 +13,7 @@
 #include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int slsttl_0_(int n__, char *cttl, char *cside, real *px, 
 	real *py, real *ht, integer *nt, ftnlen cttl_len, ftnlen cside_len)
@@ -31,7 +31,7 @@
     static real htz[5], pxz[5], pyz[5];
     extern integer lenc_(char *, ftnlen);
     static integer index;
-    static char cttlw[100], cttlz[100*5];
+    static char cttlw[2048], cttlz[2048*5];
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
     static char csidez[1*5];
     extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), sglget_(
@@ -66,7 +66,14 @@
 		ftnlen)6, (ftnlen)29);
     }
     lset[*nt - 1] = TRUE_;
-    s_copy(cttlz + (*nt - 1) * 100, cttl, (ftnlen)100, lenc_(cttl, cttl_len));
+    if (lenc_(cttl, cttl_len) > 1024) {
+	msgdmp_("W", "SLSTTL", "STRING LENGTH TOO LONG.SHORTEND.", (ftnlen)1, 
+		(ftnlen)6, (ftnlen)32);
+	s_copy(cttlz + (*nt - 1 << 11), cttl, (ftnlen)2048, (ftnlen)1024);
+    } else {
+	s_copy(cttlz + (*nt - 1 << 11), cttl, (ftnlen)2048, lenc_(cttl, 
+		cttl_len));
+    }
     *(unsigned char *)&csidez[*nt - 1] = *(unsigned char *)cs;
     pxz[*nt - 1] = *px;
     pyz[*nt - 1] = *py;
@@ -91,8 +98,8 @@ L_slpttl:
     }
     for (i__ = 1; i__ <= 5; ++i__) {
 	if (lset[i__ - 1]) {
-	    sltlcv_(cttlz + (i__ - 1) * 100, cttlw, &lc, (ftnlen)100, (ftnlen)
-		    100);
+	    sltlcv_(cttlz + (i__ - 1 << 11), cttlw, &lc, (ftnlen)2048, (
+		    ftnlen)2048);
 	    slzttl_(csidez + (i__ - 1), cttlw, &pxz[i__ - 1], &pyz[i__ - 1], &
 		    htz[i__ - 1], &index, (ftnlen)1, lc);
 	}
