@@ -64,7 +64,7 @@ static integer c__0 = 0;
     static logical lsep, lkey, lwnd;
     static char cttl[80];
     extern integer lenz_(char *, ftnlen);
-    static char cout[80];
+    static char cout[1024];
     static integer isup, irst;
     extern /* Subroutine */ int zgselectfont_(char *, ftnlen);
     static logical lfgbg;
@@ -204,7 +204,7 @@ static integer c__0 = 0;
 	swiget_("IHEIGHT", &iheigh, (ftnlen)7);
 	swiget_("ICLRMAP", &iclrmp, (ftnlen)7);
 	swlget_("LFGBG  ", &lfgbg, (ftnlen)7);
-	swcget_("FNAME  ", cout, (ftnlen)7, (ftnlen)80);
+	swcget_("FNAME  ", cout, (ftnlen)7, (ftnlen)1024);
 	swcget_("TITLE  ", cttl, (ftnlen)7, (ftnlen)80);
 	swiget_("IDMPDGT ", &idmpdgt, (ftnlen)8);
 	swiget_("IBGPAGE ", &ibgpage, (ftnlen)8);
@@ -225,13 +225,13 @@ static integer c__0 = 0;
 	    msgdmp_("E", "SWDOPN", "COLORMAP FILE DOES NOT EXIST.", (ftnlen)1,
 		     (ftnlen)6, (ftnlen)29);
 	}
-	if (s_cmp(cout, " ", (ftnlen)80, (ftnlen)1) == 0 || s_cmp(cout, "*", (
-		ftnlen)80, (ftnlen)1) == 0) {
-	    osgarg_(&c__0, cout, (ftnlen)80);
+	if (s_cmp(cout, " ", (ftnlen)1024, (ftnlen)1) == 0 || s_cmp(cout, 
+		"*", (ftnlen)1024, (ftnlen)1) == 0) {
+	    osgarg_(&c__0, cout, (ftnlen)1024);
 	}
-	if (s_cmp(cout, " ", (ftnlen)80, (ftnlen)1) == 0) {
-	    s_copy(cout, "DCL", (ftnlen)80, (ftnlen)3);
-	    clower_(cout, (ftnlen)80);
+	if (s_cmp(cout, " ", (ftnlen)1024, (ftnlen)1) == 0) {
+	    s_copy(cout, "DCL", (ftnlen)1024, (ftnlen)3);
+	    clower_(cout, (ftnlen)1024);
 	}
 	if (s_cmp(cttl, " ", (ftnlen)80, (ftnlen)1) == 0 || s_cmp(cttl, "*", (
 		ftnlen)80, (ftnlen)1) == 0) {
@@ -281,7 +281,7 @@ static integer c__0 = 0;
     zgdopn_(&jws, &iwidth, &iheigh, &iposx, &iposy, &idmpdgt, &ibgpage, &
 	    rlwfact, &lwait, &lwait0, &lwait1, &lalt, &lstdot, &lkey, &ldump, 
 	    &lwnd, &lfgbg, &lsep, &ifl, cimgfmt, &rimgcmp, clrmap, cbtmap, 
-	    cout, cttl, (ftnlen)8, (ftnlen)1024, (ftnlen)1024, (ftnlen)80, (
+	    cout, cttl, (ftnlen)8, (ftnlen)1024, (ftnlen)1024, (ftnlen)1024, (
 	    ftnlen)80);
     lopen = TRUE_;
     return 0;
