@@ -1,6 +1,13 @@
-/* src/grph1/szpack/szfont.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -8,7 +15,7 @@
 /* ----------------------------------------------------------------------- */
 /*     FONT LOADING */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int szfont_(integer *ifont, integer *iposx, integer *nchar, 
 	char *ckx, char *cky, integer *len, ftnlen ckx_len, ftnlen cky_len)
@@ -27,7 +34,7 @@
 
     /* Local variables */
     static integer iu;
-    static char cdsn[80], cpara[8];
+    static char cdsn[1024], cpara[8];
     extern /* Subroutine */ int chngi_(char *, char *, integer *, char *, 
 	    ftnlen, ftnlen, ftnlen), msgdmp_(char *, char *, char *, ftnlen, 
 	    ftnlen, ftnlen);
@@ -57,8 +64,8 @@
 /*     / INQUIRE FONT FILE NAMES / */
     s_copy(cpara, "FONT#", (ftnlen)8, (ftnlen)5);
     chngi_(cpara, "#", ifont, "(I1)", (ftnlen)8, (ftnlen)1, (ftnlen)4);
-    swqfnm_(cpara, cdsn, (ftnlen)8, (ftnlen)80);
-    if (s_cmp(cdsn, " ", (ftnlen)80, (ftnlen)1) == 0) {
+    swqfnm_(cpara, cdsn, (ftnlen)8, (ftnlen)1024);
+    if (s_cmp(cdsn, " ", (ftnlen)1024, (ftnlen)1) == 0) {
 	msgdmp_("E", "SZFONT", "FONT FILE DOES NOT EXIST.", (ftnlen)1, (
 		ftnlen)6, (ftnlen)25);
     }
@@ -66,7 +73,7 @@
     iu = iufopn_();
     o__1.oerr = 0;
     o__1.ounit = iu;
-    o__1.ofnmlen = 80;
+    o__1.ofnmlen = 1024;
     o__1.ofnm = cdsn;
     o__1.orl = 0;
     o__1.osta = 0;
