@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -15,7 +15,7 @@
 /* ----------------------------------------------------------------------- */
 /*     LINE INDEX ATTRIBUTE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int szsidx_0_(int n__, integer *index)
 {
@@ -23,15 +23,22 @@
 
     static logical lfrst = TRUE_;
 
-    static integer ibgcli, iclidx;
+    /* System generated locals */
+    logical L__1;
+
+    /* Local variables */
+    static integer ibgcli, ifcidx;
+    static logical lfcatr;
+    static integer iclidx;
     static logical lclatr;
-    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen);
+    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), swqfcc_(
+	    logical *);
     static integer iwdidx;
     extern /* Subroutine */ int swqclc_(logical *);
     static logical lwdatr;
     static integer indexz;
-    extern /* Subroutine */ int swscli_(integer *), swqwdc_(logical *), 
-	    swswdi_(integer *);
+    extern /* Subroutine */ int swscli_(integer *, logical *), swqwdc_(
+	    logical *), swswdi_(integer *);
 
     switch(n__) {
 	case 1: goto L_szqidx;
@@ -44,12 +51,13 @@
 	lfrst = FALSE_;
     }
     sgiget_("IBGCLI", &ibgcli, (ftnlen)6);
+    sgiget_("IFCIDX", &ifcidx, (ftnlen)6);
     iwdidx = indexz % 10;
     iclidx = indexz / 10;
     if (iclidx == ibgcli) {
 	iclidx = 0;
     } else {
-	iclidx %= 100;
+	iclidx %= 1000;
 	if (iclidx == 0) {
 	    iclidx = 1;
 	}
@@ -60,7 +68,9 @@
 	iclidx = iwdidx;
     }
     swswdi_(&iwdidx);
-    swscli_(&iclidx);
+    swqfcc_(&lfcatr);
+    L__1 = ! lfcatr;
+    swscli_(&iclidx, &L__1);
     return 0;
 /* ----------------------------------------------------------------------- */
 
