@@ -33,9 +33,6 @@ struct {
 
 static logical c_true = TRUE_;
 static integer c__92 = 92;
-static integer c__32 = 32;
-static integer c__180 = 180;
-static integer c__182 = 182;
 
 /* ----------------------------------------------------------------------- */
 /*     BASIC TEXT PRIMITIVE ON VC */
@@ -60,7 +57,7 @@ static integer c__182 = 182;
 
     /* Local variables */
     static char fontname[70];
-    static integer i__, j, k, n, nc, ip;
+    static integer i__, j, k, nc, ip;
     static real xc, yc;
     static integer nx, ny;
     static real xp, yp, wx, wy, vx1, wx1[2048], wx2[2048], vx2;
@@ -82,24 +79,20 @@ static integer c__182 = 182;
     static real wych;
     static integer isup, irst, mode0, imode;
     static char charx[2048];
-    static logical lmark;
-    static integer index, idest;
+    static integer index;
     static char charz[2048];
     static real factz, irota;
     static integer ifont;
     static real xrate, yrate;
-    static integer nskip, isubz;
+    static integer isubz;
     static real rxmin, rxmax, rymin, rymax;
     static integer iposx[2048];
     static real wxmin, wxmax, wymin, wymax;
     static integer iwtrf, isupz, irstz;
     extern /* Subroutine */ int swsfw_(integer *), swtxt_(real *, real *, 
-	    real *, char *, integer *, real *, integer *, ftnlen);
-    static integer iocmde, iocmod;
-    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), sglget_(
-	    char *, logical *, ftnlen), msgdmp_(char *, char *, char *, 
-	    ftnlen, ftnlen, ftnlen), swcget_(char *, char *, ftnlen, ftnlen), 
-	    swftfc_(char *, ftnlen);
+	    real *, char *, integer *, real *, integer *, ftnlen), sgiget_(
+	    char *, integer *, ftnlen), sglget_(char *, logical *, ftnlen), 
+	    swcget_(char *, char *, ftnlen, ftnlen), swftfc_(char *, ftnlen);
     static logical lfprop;
     extern /* Subroutine */ int swscli_(integer *, logical *), swlget_(char *,
 	     logical *, ftnlen);
@@ -109,8 +102,9 @@ static integer c__182 = 182;
 	    char *, ftnlen, ftnlen), szqfnw_(real *, real *), stfwtr_(real *, 
 	    real *, real *, real *), szplsv_(real *, real *), stqwtr_(real *, 
 	    real *, real *, real *, real *, real *, real *, real *, integer *)
-	    , szopsv_(void), szmvsv_(real *, real *), szqtxw_(char *, integer 
-	    *, real *, real *, ftnlen);
+	    , sztxno_(char *, char *, logical *, ftnlen, ftnlen), szopsv_(
+	    void), szmvsv_(real *, real *), szqtxw_(char *, integer *, real *,
+	     real *, ftnlen);
     static logical lmrkfnt, lsysfnt;
 
     lcntlz = szbtx2_1.lcntl;
@@ -224,134 +218,8 @@ static integer c__182 = 182;
 	*(unsigned char *)&charx[i__ - 1] = '\0';
 /* L998: */
     }
-/*     / CONVERT NEW TYPE MARKUPS TO OLD ONE / */
-    ncz = lenc_(charx, (ftnlen)2048);
-    for (n = 1; n <= 2048; ++n) {
-	s_copy(charz, " ", (ftnlen)2048, (ftnlen)1);
-/* L1: */
-    }
-    nskip = 0;
-    idest = 1;
-    imode = 0;
-    iocmde = 0;
-    lmark = TRUE_;
-    i__1 = ncz;
-    for (n = 1; n <= i__1; ++n) {
-	idx0 = isgc_(charx + (n - 1), (ftnlen)1);
-	if (idx0 == isupz || idx0 == isubz || idx0 == irstz) {
-	    csgi_(ch__1, (ftnlen)1, &c__32);
-	    *(unsigned char *)&charx[n - 1] = *(unsigned char *)&ch__1[0];
-	    idx0 = isgc_(charx + (n - 1), (ftnlen)1);
-	}
-	if (imode == 1) {
-	    if (idx0 == 94) {
-		lcntlz = TRUE_;
-		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)csup;
-		++idest;
-	    } else if (idx0 == 95) {
-		lcntlz = TRUE_;
-		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)csub;
-		++idest;
-	    } else if (idx0 == 111) {
-/*           180: UP ARROW */
-		csgi_(ch__1, (ftnlen)1, &c__180);
-		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
-			ch__1[0];
-		++idest;
-		msgdmp_("W", "SZTXWV", "TOPBAR IS NOT SUPPORT IN STROKEFONT", 
-			(ftnlen)1, (ftnlen)6, (ftnlen)35);
-		lmark = FALSE_;
-	    } else if (idx0 == 117) {
-/*           182: DOWN ARROW */
-		csgi_(ch__1, (ftnlen)1, &c__182);
-		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
-			ch__1[0];
-		++idest;
-		msgdmp_("W", "SZTXWV", "UNDERBAR IS NOT SUPPORT IN STROKEFONT"
-			, (ftnlen)1, (ftnlen)6, (ftnlen)37);
-		lmark = FALSE_;
-	    } else if (idx0 == 92) {
-		csgi_(ch__1, (ftnlen)1, &c__92);
-		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
-			ch__1[0];
-		++idest;
-		imode = 0;
-	    } else if (idx0 == 123) {
-		imode = 2;
-	    } else {
-		imode = 0;
-		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
-			charx[n - 1];
-		++idest;
-		if (lmark) {
-		    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)
-			    crst;
-		    ++idest;
-		} else {
-		    lmark = TRUE_;
-		}
-	    }
-	} else if (imode == 2) {
-	    if (isgc_(charx + (n - 1), (ftnlen)1) == 125) {
-		imode = 0;
-		if (lmark) {
-		    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)
-			    crst;
-		    ++idest;
-		} else {
-		    lmark = TRUE_;
-		}
-	    } else {
-		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
-			charx[n - 1];
-		++idest;
-	    }
-/*       92:\ 94:^ 95:_ 111:o 117:u 123:{ 125:} */
-	} else if (idx0 == 92) {
-	    imode = 1;
-/* OLD TYPE CONTROL */
-	} else if (idx0 == isup && szbtx2_1.lcntl) {
-	    csgi_(ch__1, (ftnlen)1, &isup);
-	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)&ch__1[0];
-	    iocmde = idest;
-	    ++idest;
-	} else if (idx0 == isub && szbtx2_1.lcntl) {
-	    csgi_(ch__1, (ftnlen)1, &isub);
-	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)&ch__1[0];
-	    iocmde = -idest;
-	    ++idest;
-	} else if (idx0 == irst && szbtx2_1.lcntl) {
-	    if (iocmde > 0) {
-		*(unsigned char *)&charz[iocmde - 1] = *(unsigned char *)csup;
-		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)crst;
-		++idest;
-		iocmod = 0;
-	    } else if (iocmde < 0) {
-		i__2 = -iocmde - 1;
-		s_copy(charz + i__2, csub, -iocmde - i__2, (ftnlen)1);
-		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)crst;
-		++idest;
-		iocmod = 0;
-	    } else {
-		csgi_(ch__1, (ftnlen)1, &irst);
-		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
-			ch__1[0];
-		iocmde = 0;
-		++idest;
-	    }
-	} else {
-	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)&charx[n 
-		    - 1];
-	    ++idest;
-	}
-/* L3: */
-    }
-    if (idest <= ncz) {
-	ncz = idest - 1;
-    }
-/*  / END CONVERT MARKUPS / */
-    lcntlz = TRUE_;
-    szqtxw_(charz, &nc, &wxch, &wych, (ftnlen)2048);
+    sztxno_(chars, charz, &lcntlz, chars_len, (ftnlen)2048);
+    szqtxw_(chars, &nc, &wxch, &wych, chars_len);
 /*     / CALCULATE OFFSET VALUES / */
     offx = wxch * -.5f * 24.f * (szbtx1_1.icentz + 1);
     offy = 0.f;
