@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -13,7 +13,7 @@
 #include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int grstrf_(void)
 {
@@ -85,8 +85,7 @@
 	    msgdmp_("E", "GRSTRF", "VYOFF IS NOT DEFINED.", (ftnlen)1, (
 		    ftnlen)6, (ftnlen)21);
 	}
-    } else if (10 <= itr && itr <= 15 || 20 <= itr && itr <= 23 || 30 <= itr 
-	    && itr <= 33) {
+    } else if (10 <= itr && itr <= 24 || 30 <= itr && itr <= 34) {
 	sgrget_("SIMFAC", &simfac, (ftnlen)6);
 	if (simfac == rundef) {
 	    msgdmp_("E", "GRSTRF", "SIMFAC IS NOT DEFINED.", (ftnlen)1, (
