@@ -1,6 +1,13 @@
-/* src/grph2/oldsrc/uflnu.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -8,7 +15,7 @@
 /* ----------------------------------------------------------------------- */
 /*     UFPACK */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uflnu_0_(int n__, real *ux1, real *uy1, real *ux2, real *
 	uy2, real *vx1, real *vy1, real *vx2, real *vy2, real *rx1, real *ry1,
