@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -18,22 +18,22 @@ static real c_b13 = 1.f;
 static logical c_true = TRUE_;
 static integer c__10 = 10;
 static integer c__1 = 1;
-static real c_b28 = 10.f;
-static integer c__4 = 4;
+static real c_b29 = 10.f;
+static integer c__3 = 3;
 static integer c__2 = 2;
 static integer c__16 = 16;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ulxlog_(char *cside, integer *nlbl, integer *nticks, 
 	ftnlen cside_len)
 {
     /* System generated locals */
-    address a__1[4], a__2[2];
-    integer i__1, i__2, i__3, i__4[4], i__5[2];
+    address a__1[3], a__2[2];
+    integer i__1, i__2, i__3, i__4[3], i__5[2];
     real r__1, r__2;
-    char ch__1[1], ch__2[1], ch__3[7];
+    char ch__1[3], ch__2[3], ch__3[7];
     icilist ici__1;
 
     /* Builtin functions */
@@ -44,7 +44,7 @@ static integer c__16 = 16;
 	     char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static char ch[16*50];
+    static char ch[18*50];
     static integer ib;
     static real bl[10];
     static integer nb;
@@ -55,11 +55,11 @@ static integer c__16 = 16;
     static char chr[8], chw[16];
     static integer nbs, nbt;
     static real sgn, uxt[50], xxx;
-    extern /* Subroutine */ int gnge_(real *, real *, integer *);
-    extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
+    extern /* Subroutine */ int gnge_(real *, real *, integer *), gnle_(real *
+	    , real *, integer *);
     static logical loff;
-    extern /* Subroutine */ int gnle_(real *, real *, integer *);
     static char cfmt[16];
+    extern /* Character */ VOID usgi_(char *, ftnlen, integer *);
     extern logical lrgt_(real *, real *);
     extern integer lenz_(char *, ftnlen);
     static real xmin;
@@ -74,7 +74,9 @@ static integer c__16 = 16;
     static integer ixchr, ipmax;
     static logical lepsl;
     static real bxmax, bxmin;
-    static integer ipmin, itype;
+    static integer ipmin;
+    static logical lsfnt;
+    static integer itype;
     extern /* Subroutine */ int vrgnn_(real *, integer *, integer *);
     static integer jtype;
     static real uxmin, uymin, uxmax, uymax, factor;
@@ -87,14 +89,14 @@ static integer c__16 = 16;
     extern /* Subroutine */ int uzcget_(char *, char *, ftnlen, ftnlen), 
 	    ulxlbl_(real *, integer *, integer *), sgqwnd_(real *, real *, 
 	    real *, real *), gnrset_(void), sgswnd_(real *, real *, real *, 
-	    real *), uxplbl_(char *, integer *, real *, char *, integer *, 
-	    integer *, ftnlen, ftnlen), sgstrf_(void), uzlget_(char *, 
-	    logical *, ftnlen), uzrget_(char *, real *, ftnlen), uxpaxs_(char 
-	    *, integer *, ftnlen), uxptmk_(char *, integer *, real *, integer 
-	    *, ftnlen);
+	    real *), swlget_(char *, logical *, ftnlen), uxplbl_(char *, 
+	    integer *, real *, char *, integer *, integer *, ftnlen, ftnlen), 
+	    sgstrf_(void), uzlget_(char *, logical *, ftnlen), uzrget_(char *,
+	     real *, ftnlen), uxpaxs_(char *, integer *, ftnlen), uxptmk_(
+	    char *, integer *, real *, integer *, ftnlen);
 
     /* Fortran I/O blocks */
-    static icilist io___35 = { 0, chr, 0, "(I8)", 8, 1 };
+    static icilist io___36 = { 0, chr, 0, "(I8)", 8, 1 };
 
 
 /*     CSIDE : 'T','B','U' */
@@ -137,6 +139,7 @@ static integer c__16 = 16;
     sgiget_("IRST", &irst, (ftnlen)4);
     gllget_("LEPSL", &lepsl, (ftnlen)5);
     sglget_("LCNTL", &lcntl, (ftnlen)5);
+    swlget_("LSYSFNT", &lsfnt, (ftnlen)7);
     gllset_("LEPSL", &c_true, (ftnlen)5);
     gnsave_();
 /*     SMALL TICKS */
@@ -164,7 +167,7 @@ static integer c__16 = 16;
 		msgdmp_("E", "ULXLOG", "TOO MANY TICKS.", (ftnlen)1, (ftnlen)
 			6, (ftnlen)15);
 	    }
-	    ux1[nbs - 1] = sgn * bs[ib - 1] * pow_ri(&c_b28, &ip);
+	    ux1[nbs - 1] = sgn * bs[ib - 1] * pow_ri(&c_b29, &ip);
 L100:
 	    ;
 	}
@@ -191,20 +194,20 @@ L100:
 	    }
 	    if (ib == 1) {
 		++nbt;
-		uxt[nbt - 1] = sgn * pow_ri(&c_b28, &ip);
+		uxt[nbt - 1] = sgn * pow_ri(&c_b29, &ip);
 	    }
 	    ++nbl;
 	    if (nbl > 50) {
 		msgdmp_("E", "ULXLOG", "TOO MANY LABELS.", (ftnlen)1, (ftnlen)
 			6, (ftnlen)16);
 	    }
-	    ux2[nbl - 1] = sgn * bl[ib - 1] * pow_ri(&c_b28, &ip);
+	    ux2[nbl - 1] = sgn * bl[ib - 1] * pow_ri(&c_b29, &ip);
 	    if (itype <= 2) {
 		if (jtype == 0 && ib != 1) {
 		    ici__1.icierr = 0;
 		    ici__1.icirnum = 1;
-		    ici__1.icirlen = 16;
-		    ici__1.iciunit = ch + (nbl - 1 << 4);
+		    ici__1.icirlen = 18;
+		    ici__1.iciunit = ch + (nbl - 1) * 18;
 		    ici__1.icifmt = "(I1)";
 		    s_wsfi(&ici__1);
 		    i__3 = (integer) bl[ib - 1];
@@ -214,50 +217,38 @@ L100:
 		    if (jtype == 1 && nb != 1) {
 			ici__1.icierr = 0;
 			ici__1.icirnum = 1;
-			ici__1.icirlen = 16;
-			ici__1.iciunit = ch + (nbl - 1 << 4);
-			ici__1.icifmt = "(I1,A1)";
+			ici__1.icirlen = 18;
+			ici__1.iciunit = ch + (nbl - 1) * 18;
+			ici__1.icifmt = "(I1,A3)";
 			s_wsfi(&ici__1);
 			i__3 = (integer) bl[ib - 1];
 			do_fio(&c__1, (char *)&i__3, (ftnlen)sizeof(integer));
-			csgi_(ch__2, (ftnlen)1, &ixchr);
-			*(unsigned char *)&ch__1[0] = *(unsigned char *)&
-				ch__2[0];
-			do_fio(&c__1, ch__1, (ftnlen)1);
+			usgi_(ch__2, (ftnlen)3, &ixchr);
+			s_copy(ch__1, ch__2, (ftnlen)3, (ftnlen)3);
+			do_fio(&c__1, ch__1, (ftnlen)3);
 			e_wsfi();
 		    } else {
-			s_copy(ch + (nbl - 1 << 4), " ", (ftnlen)16, (ftnlen)
+			s_copy(ch + (nbl - 1) * 18, " ", (ftnlen)18, (ftnlen)
 				1);
 		    }
-		    s_wsfi(&io___35);
+		    s_wsfi(&io___36);
 		    do_fio(&c__1, (char *)&ip, (ftnlen)sizeof(integer));
 		    e_wsfi();
 		    cladj_(chr, (ftnlen)8);
-		    if (lcntl) {
 /* Writing concatenation */
-			i__4[0] = 2, a__1[0] = "10";
-			csgi_(ch__1, (ftnlen)1, &isup);
-			i__4[1] = 1, a__1[1] = ch__1;
-			i__4[2] = lenz_(chr, (ftnlen)8), a__1[2] = chr;
-			csgi_(ch__2, (ftnlen)1, &irst);
-			i__4[3] = 1, a__1[3] = ch__2;
-			s_cat(ch + ((nbl - 1 << 4) + 2), a__1, i__4, &c__4, (
-				ftnlen)14);
-		    } else {
-/* Writing concatenation */
-			i__5[0] = 1, a__2[0] = "E";
-			i__5[1] = 8, a__2[1] = chr;
-			s_cat(ch + ((nbl - 1 << 4) + 1), a__2, i__5, &c__2, (
-				ftnlen)15);
-		    }
-		    cladj_(ch + (nbl - 1 << 4), (ftnlen)16);
+		    i__4[0] = 5, a__1[0] = "10\\^{";
+		    i__4[1] = lenz_(chr, (ftnlen)8), a__1[1] = chr;
+		    i__4[2] = 1, a__1[2] = "}";
+		    s_cat(ch + ((nbl - 1) * 18 + 4), a__1, i__4, &c__3, (
+			    ftnlen)14);
+		    cladj_(ch + (nbl - 1) * 18, (ftnlen)18);
 		}
 	    } else {
 		if (jtype == 0 && ib != 1) {
 		    ici__1.icierr = 0;
 		    ici__1.icirnum = 1;
-		    ici__1.icirlen = 16;
-		    ici__1.iciunit = ch + (nbl - 1 << 4);
+		    ici__1.icirlen = 18;
+		    ici__1.iciunit = ch + (nbl - 1) * 18;
 		    ici__1.icifmt = "(I1)";
 		    s_wsfi(&ici__1);
 		    i__3 = (integer) bl[ib - 1];
@@ -266,9 +257,9 @@ L100:
 		} else {
 		    uzcget_("CXFMT", cfmt, (ftnlen)5, (ftnlen)16);
 		    r__2 = (r__1 = ux2[nbl - 1], abs(r__1));
-		    chval_(cfmt, &r__2, ch + (nbl - 1 << 4), (ftnlen)16, (
-			    ftnlen)16);
-		    cladj_(ch + (nbl - 1 << 4), (ftnlen)16);
+		    chval_(cfmt, &r__2, ch + (nbl - 1) * 18, (ftnlen)16, (
+			    ftnlen)18);
+		    cladj_(ch + (nbl - 1) * 18, (ftnlen)18);
 		}
 	    }
 L201:
@@ -280,9 +271,9 @@ L201:
 	for (ib = 1; ib <= i__1; ++ib) {
 /* Writing concatenation */
 	    i__5[0] = 1, a__2[0] = "-";
-	    i__5[1] = 16, a__2[1] = ch + (ib - 1 << 4);
+	    i__5[1] = 18, a__2[1] = ch + (ib - 1) * 18;
 	    s_cat(chw, a__2, i__5, &c__2, (ftnlen)16);
-	    s_copy(ch + (ib - 1 << 4), chw, (ftnlen)16, (ftnlen)16);
+	    s_copy(ch + (ib - 1) * 18, chw, (ftnlen)18, (ftnlen)16);
 /* L301: */
 	}
     }
@@ -300,7 +291,7 @@ L201:
     s_cat(ch__3, a__2, i__5, &c__2, (ftnlen)7);
     uzlget_(ch__3, &label, (ftnlen)7);
     if (label) {
-	uxplbl_(cside, &c__1, ux2, ch, &c__16, &nbl, (ftnlen)1, (ftnlen)16);
+	uxplbl_(cside, &c__1, ux2, ch, &c__16, &nbl, (ftnlen)1, (ftnlen)18);
     }
     gllset_("LEPSL", &lepsl, (ftnlen)5);
     gnrset_();
