@@ -1,6 +1,13 @@
-/* src/grph2/umpack/umiqnp.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -13,7 +20,7 @@ static integer c__11 = 11;
 /* ----------------------------------------------------------------------- */
 /*     UMIQNP / UMIQID / UMIQCP / UMIQVL / UMISVL */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int umiqnp_0_(int n__, integer *ncp, char *cp, integer *idx, 
 	integer *ipara, integer *in, ftnlen cp_len)
@@ -23,7 +30,7 @@ static integer c__11 = 11;
     static char cparas[8*11] = "INDEXMJ " "INDEXMN " "ITYPEMJ " "ITYPEMN " 
 	    "INDEXBND" "MAXBND  " "IGROUP  " "INDEXOUT" "ITYPEOUT" "IPATLAND" 
 	    "IPATLAKE";
-    static integer ix[11] = { 3,1,1,3,3,300,1,1,1,1999,99999 };
+    static integer ix[11] = { 3,1,1,3,3,300,1,1,1,1999,9999 };
     static char cparal[40*11] = "MAP_MAJOR_LINE_INDEX                    " 
 	    "MAP_MINOR_LINE_INDEX                    " "MAP_MAJOR_LINE_TYPE "
 	    "                    " "MAP_MINOR_LINE_TYPE                     " 
