@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -15,22 +15,22 @@
 /* Table of constant values */
 
 static integer c__194 = 194;
-static integer c__3 = 3;
 static integer c__4 = 4;
+static integer c__3 = 3;
 
 /* ----------------------------------------------------------------------- */
 /*     USPACK GET CHARACTER FOR SUBLABEL               S.Sakai  90/02/24 */
 /*                                                              92/02/27 */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Character */ VOID csblbl_(char *ret_val, ftnlen ret_val_len, real *ufac, 
 	real *uoff, char *cunit__, ftnlen cunit_len)
 {
     /* System generated locals */
-    address a__1[3], a__2[4];
-    integer i__1[3], i__2[4];
-    char ch__2[1];
+    address a__1[4], a__2[3];
+    integer i__1[4], i__2[3];
+    char ch__2[3];
 
     /* Builtin functions */
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
@@ -39,8 +39,8 @@ static integer c__4 = 4;
     /* Local variables */
     static integer nlf, nls;
     extern integer lenc_(char *, ftnlen);
-    extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
     static char csub[32];
+    extern /* Character */ VOID usgi_(char *, ftnlen, integer *);
     extern integer lenz_(char *, ftnlen);
     static char chfac[16];
     extern /* Subroutine */ int cladj_(char *, ftnlen);
@@ -56,13 +56,13 @@ static integer c__4 = 4;
     }
     if (*ufac != 1.f) {
 	uschvl_(ufac, chfac, (ftnlen)16);
-	csgi_(ch__2, (ftnlen)1, &c__194);
-	*(unsigned char *)chfac = *(unsigned char *)&ch__2[0];
 /* Writing concatenation */
-	i__1[0] = lenc_(chfac, (ftnlen)16), a__1[0] = chfac;
-	i__1[1] = 1, a__1[1] = " ";
-	i__1[2] = 16, a__1[2] = choff;
-	s_cat(csub, a__1, i__1, &c__3, (ftnlen)32);
+	usgi_(ch__2, (ftnlen)3, &c__194);
+	i__1[0] = 3, a__1[0] = ch__2;
+	i__1[1] = lenc_(chfac, (ftnlen)16) - 1, a__1[1] = chfac + 1;
+	i__1[2] = 1, a__1[2] = " ";
+	i__1[3] = 16, a__1[3] = choff;
+	s_cat(csub, a__1, i__1, &c__4, (ftnlen)32);
     } else if (*uoff != 0.f) {
 	s_copy(csub, choff, (ftnlen)32, (ftnlen)16);
     } else {
@@ -75,25 +75,25 @@ static integer c__4 = 4;
     if (nlf != 0) {
 	if (nls != 0) {
 /* Writing concatenation */
-	    i__2[0] = 1, a__2[0] = cblkt;
-	    i__2[1] = nlf + 1, a__2[1] = ret_val;
-	    i__2[2] = nls, a__2[2] = cunit__;
-	    i__2[3] = 1, a__2[3] = cblkt + 1;
-	    s_cat(csub, a__2, i__2, &c__4, (ftnlen)32);
+	    i__1[0] = 1, a__1[0] = cblkt;
+	    i__1[1] = nlf + 1, a__1[1] = ret_val;
+	    i__1[2] = nls, a__1[2] = cunit__;
+	    i__1[3] = 1, a__1[3] = cblkt + 1;
+	    s_cat(csub, a__1, i__1, &c__4, (ftnlen)32);
 	} else {
 /* Writing concatenation */
-	    i__1[0] = 1, a__1[0] = cblkt;
-	    i__1[1] = nlf, a__1[1] = ret_val;
-	    i__1[2] = 1, a__1[2] = cblkt + 1;
-	    s_cat(csub, a__1, i__1, &c__3, (ftnlen)32);
+	    i__2[0] = 1, a__2[0] = cblkt;
+	    i__2[1] = nlf, a__2[1] = ret_val;
+	    i__2[2] = 1, a__2[2] = cblkt + 1;
+	    s_cat(csub, a__2, i__2, &c__3, (ftnlen)32);
 	}
     } else {
 	if (nls != 0) {
 /* Writing concatenation */
-	    i__1[0] = 1, a__1[0] = cblkt;
-	    i__1[1] = nls, a__1[1] = cunit__;
-	    i__1[2] = 1, a__1[2] = cblkt + 1;
-	    s_cat(csub, a__1, i__1, &c__3, (ftnlen)32);
+	    i__2[0] = 1, a__2[0] = cblkt;
+	    i__2[1] = nls, a__2[1] = cunit__;
+	    i__2[2] = 1, a__2[2] = cblkt + 1;
+	    s_cat(csub, a__2, i__2, &c__3, (ftnlen)32);
 	} else {
 	    s_copy(csub, " ", (ftnlen)32, (ftnlen)1);
 	}
