@@ -1,6 +1,13 @@
-/* src/grph2/uspack/usaxdv.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -12,7 +19,7 @@ static logical c_true = TRUE_;
 /* ----------------------------------------------------------------------- */
 /*     USPACK AXIS (UNIFORM TICK MARK)                 S.Sakai  99/09/30 */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int usaxdv_(char *cside, real *dtick, real *dlbl, ftnlen 
 	cside_len)
@@ -28,11 +35,12 @@ static logical c_true = TRUE_;
     static logical loff;
     extern integer lenz_(char *, ftnlen);
     static real factor, offset;
-    extern /* Subroutine */ int cupper_(char *, ftnlen), uzlget_(char *, 
-	    logical *, ftnlen), uxaxdv_(char *, real *, real *, ftnlen), 
-	    uyaxdv_(char *, real *, real *, ftnlen), uzlset_(char *, logical *
-	    , ftnlen), usxinz_(char *, real *, real *, ftnlen), usyinz_(char *
-	    , real *, real *, ftnlen), usxtlz_(void), usytlz_(void);
+    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
+	    ftnlen, ftnlen), cupper_(char *, ftnlen), uzlget_(char *, logical 
+	    *, ftnlen), uxaxdv_(char *, real *, real *, ftnlen), uyaxdv_(char 
+	    *, real *, real *, ftnlen), uzlset_(char *, logical *, ftnlen), 
+	    usxinz_(char *, real *, real *, ftnlen), usyinz_(char *, real *, 
+	    real *, ftnlen), usxtlz_(void), usytlz_(void);
 
     uzlget_("LOFFSET", &loff, (ftnlen)7);
     uzlset_("LOFFSET", &c_true, (ftnlen)7);
@@ -61,6 +69,9 @@ static logical c_true = TRUE_;
 	    r__2 = *dlbl / factor;
 	    uyaxdv_(cs, &r__1, &r__2, (ftnlen)1);
 	    usytlz_();
+	} else {
+	    msgdmp_("E", "USAXDV", "INVALID SIDE NAME.", (ftnlen)1, (ftnlen)6,
+		     (ftnlen)18);
 	}
 /* L100: */
     }
