@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -25,7 +25,7 @@ struct {
 static integer c__1 = 1;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uvbrfz_(integer *n, real *upx, real *upy1, real *upy2, 
 	integer *itype, integer *index, real *rsize)
@@ -56,10 +56,9 @@ static integer c__1 = 1;
 	    *, logical *, ftnlen), msgdmp_(char *, char *, char *, ftnlen, 
 	    ftnlen, ftnlen), sgrget_(char *, real *, ftnlen), stftrf_(real *, 
 	    real *, real *, real *), swocls_(char *, ftnlen), uurget_(char *, 
-	    real *, ftnlen), uuqidv_(real *, real *), szcllv_(void), szsidx_(
-	    integer *), swoopn_(char *, char *, ftnlen, ftnlen), szpllv_(real 
-	    *, real *), szoplv_(void), szmvlv_(real *, real *), szstyp_(
-	    integer *);
+	    real *, ftnlen), uuqidv_(real *, real *), szcllv_(void), swoopn_(
+	    char *, char *, ftnlen, ftnlen), szslti_(integer *, integer *), 
+	    szpllv_(real *, real *), szoplv_(void), szmvlv_(real *, real *);
 
     /* Fortran I/O blocks */
     static icilist io___5 = { 0, cobj, 0, "(2I8,F8.5)", 80, 1 };
@@ -109,8 +108,7 @@ static integer c__1 = 1;
     e_wsfi();
     cdblk_(cobj, (ftnlen)80);
     swoopn_("UVBRFZ", cobj, (ftnlen)6, (ftnlen)80);
-    szsidx_(index);
-    szstyp_(itype);
+    szslti_(itype, index);
     lxuni = upx[1] == rundef;
     lyc1 = upy1[1] == rundef;
     lyc2 = upy2[1] == rundef;
