@@ -1,6 +1,13 @@
-/* src/math1/maplib/mpfcoc.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -12,7 +19,7 @@ static real c_b3 = 1.f;
 /* ----------------------------------------------------------------------- */
 /*     MAP PROJECTION (LAMBERT CONICAL 2)               93/02/20 S.SAKAI */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int mpfcoc_0_(int n__, real *xlon, real *ylat, real *x, real 
 	*y, real *ylat1, real *ylat2)
@@ -29,9 +36,9 @@ static real c_b3 = 1.f;
 
     /* Local variables */
     static real r__, s, ck, dk, pi, th, tt, th1, th2, dlm, rna;
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
-    extern doublereal xmplon_(real *);
+    extern real xmplon_(real *);
 
     switch(n__) {
 	case 1: goto L_mpicoc;
@@ -43,7 +50,7 @@ static real c_b3 = 1.f;
 	th = pi - 1e-5f;
     }
     tt = tan(th / 2.f);
-    if (dabs(tt) < 1e-6f) {
+    if (abs(tt) < 1e-6f) {
 	tt = 0.f;
     }
     d__1 = (doublereal) tt;
@@ -66,7 +73,7 @@ L_mpicoc:
 	return 0;
     } else {
 	*xlon = atan2(*x, -s * *y) / dk;
-	if (dabs(*xlon) <= pi) {
+	if (abs(*xlon) <= pi) {
 	    d__1 = (doublereal) (r__ / ck);
 	    d__2 = (doublereal) (1.f / dk);
 	    *ylat = s * (pi / 2 - atan(pow_dd(&d__1, &d__2)) * 2);
@@ -84,11 +91,11 @@ L_mpscoc:
     r__1 = *ylat1 + *ylat2;
     s = r_sign(&c_b3, &r__1);
 /* Computing MAX */
-    r__1 = dabs(*ylat1), r__2 = dabs(*ylat2);
-    th1 = pi / 2 - dmax(r__1,r__2);
+    r__1 = abs(*ylat1), r__2 = abs(*ylat2);
+    th1 = pi / 2 - max(r__1,r__2);
 /* Computing MIN */
-    r__1 = dabs(*ylat1), r__2 = dabs(*ylat2);
-    th2 = pi / 2 - dmin(r__1,r__2);
+    r__1 = abs(*ylat1), r__2 = abs(*ylat2);
+    th2 = pi / 2 - min(r__1,r__2);
     dk = (log(sin(th2)) - log(sin(th1))) / (log(tan(th2 / 2)) - log(tan(th1 / 
 	    2)));
     d__1 = (doublereal) tan(th1 / 2);
