@@ -1,6 +1,13 @@
-/* src/math1/rfblib/rcor.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -8,9 +15,9 @@
 /* ----------------------------------------------------------------------- */
 /*     RCOR */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-doublereal rcor_(real *rx, real *ry, integer *n, integer *jx, integer *jy)
+real rcor_(real *rx, real *ry, integer *n, integer *jx, integer *jy)
 {
     /* System generated locals */
     real ret_val;
@@ -19,7 +26,7 @@ doublereal rcor_(real *rx, real *ry, integer *n, integer *jx, integer *jy)
     double sqrt(doublereal);
 
     /* Local variables */
-    extern doublereal rcov_(real *, real *, integer *, integer *, integer *), 
+    extern real rcov_(real *, real *, integer *, integer *, integer *), 
 	    rvar0_(real *, integer *, integer *);
     static real rmiss, rvarx, rvary;
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen), msgdmp_(char 
