@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -20,7 +20,7 @@ static integer c__2 = 2;
 /* ----------------------------------------------------------------------- */
 /*     GET EXTERNAL PARAMETER FROM COMMAND LINE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int rpnopt_0_(int n__, char *cpfix, char *cp, integer *ipara,
 	 logical *lpara, real *rpara, char *cpara, ftnlen cpfix_len, ftnlen 
@@ -28,8 +28,9 @@ static integer c__2 = 2;
 {
     /* Initialized data */
 
-    static char copt[1] = "-";
-    static char cdiv[1] = "=";
+    static char csepx[1] = "_";
+    static char coptx[1] = "-";
+    static char cdivx[1] = "=";
 
     /* System generated locals */
     address a__1[4], a__2[2];
@@ -44,7 +45,7 @@ static integer c__2 = 2;
     static integer n, np, max__;
     static char cpx[80], carg[80];
     extern integer lenc_(char *, ftnlen);
-    static char csep[1];
+    static char cdiv[1], csep[1], copt[1];
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
     extern integer ifromc_(char *, ftnlen);
     extern logical lfromc_(char *, ftnlen);
@@ -66,15 +67,15 @@ static integer c__2 = 2;
 
     osgenv_("DCLENVCHAR", csep, (ftnlen)10, (ftnlen)1);
     if (*(unsigned char *)csep == ' ') {
-	*(unsigned char *)csep = ':';
+	*(unsigned char *)csep = *(unsigned char *)&csepx[0];
     }
     osgenv_("DCLOPTCHAR", copt, (ftnlen)10, (ftnlen)1);
-    if (*(unsigned char *)&copt[0] == ' ') {
-	*(unsigned char *)&copt[0] = '-';
+    if (*(unsigned char *)copt == ' ') {
+	*(unsigned char *)copt = *(unsigned char *)&coptx[0];
     }
     osgenv_("DCLSETCHAR", cdiv, (ftnlen)10, (ftnlen)1);
-    if (*(unsigned char *)&cdiv[0] == ' ') {
-	*(unsigned char *)&cdiv[0] = '=';
+    if (*(unsigned char *)cdiv == ' ') {
+	*(unsigned char *)cdiv = *(unsigned char *)&cdivx[0];
     }
     return 0;
 /* ----------------------------------------------------------------------- */
