@@ -9,7 +9,8 @@
 #include <string.h>
 
 #ifndef DCLVER
-#define DCLVER "dcl-ver.7.1.2"
+#define DCLVER "dcl-ver.7.2.3
+"
 #endif
 
 #ifndef WINDOWS
